@@ -2,7 +2,7 @@ from typing import Any, Dict, List
 from treebuilder.expand import expand
 
 
-def nest(source: List[Dict[str, Any]], entry: str, values: List[Any]) -> List[Dict[str, Any]]:
+def nest(source: List[Dict[str, Any]], entry: str, values: List[Any], deep_copy: bool = True) -> List[Dict[str, Any]]:
     """Nest source by a values list.
 
     Nest generates combination of source and values one by one.
@@ -17,10 +17,11 @@ def nest(source: List[Dict[str, Any]], entry: str, values: List[Any]) -> List[Di
         source (List[Dict[str, Any]]): Source list to nest.
         entry (str): Entry key under which values are stored.
         values (List[Any]): List of values to nest.
+        deep_copy (bool): Make a deep copy on values for each usages. Default is True.
 
     Returns:
         List[Dict[str, Any]]: The nested list.
     """
     if len(values) > len(source):
         values = values[0:len(source)]
-    return expand(source, entry, values)
\ No newline at end of file
+    return expand(source, entry, values, deep_copy)
\ No newline at end of file
